@@ -7,7 +7,7 @@ RDF::Trine::Iterator - Stream (iterator) class for SPARQL query results
 
 =head1 VERSION
 
-This document describes RDF::Trine::Iterator version 0.130_01.
+This document describes RDF::Trine::Iterator version 0.130_02.
 
 =head1 SYNOPSIS
 
@@ -42,7 +42,7 @@ use RDF::Trine::Iterator::SAXHandler;
 
 our ($VERSION, @ISA, @EXPORT_OK);
 BEGIN {
-	$VERSION	= '0.130_01';
+	$VERSION	= '0.130_02';
 	
 	require Exporter;
 	@ISA		= qw(Exporter);
@@ -186,10 +186,10 @@ sub from_string {
 }
 
 
-=item C<< next >>
-
 =item C<< next_result >>
 
+=item C<< next >>
+
 Returns the next item in the stream.
 
 =cut
@@ -333,7 +333,7 @@ Returns the boolean value of the first item in the stream.
 
 sub get_boolean {
 	my $self	= shift;
-	my $data	= $self->next_result;
+	my $data	= $self->next;
 	return +$data;
 }
 
@@ -373,7 +373,7 @@ sub format_node_xml ($$$$) {
 	my $node_label;
 	
 	if(!defined $node) {
-		$node_label	= "<unbound/>";
+		return;
 	} elsif ($node->is_resource) {
 		$node_label	= $node->uri_value;
 		$node_label	=~ s/&/&amp;/g;
@@ -385,7 +385,15 @@ sub format_node_xml ($$$$) {
 		$node_label	=~ s/&/&amp;/g;
 		$node_label	=~ s/</&lt;/g;
 		$node_label	=~ s/"/&quot;/g;
-		$node_label	= qq(<literal>${node_label}</literal>);
+		if ($node->has_language) {
+			my $lang	= $node->literal_value_language;
+			$node_label	= qq(<literal xml:lang="${lang}">${node_label}</literal>);
+		} elsif ($node->has_datatype) {
+			my $dt	= $node->literal_datatype;
+			$node_label	= qq(<literal datatype="${dt}">${node_label}</literal>);
+		} else {
+			$node_label	= qq(<literal>${node_label}</literal>);
+		}
 	} elsif ($node->isa('RDF::Trine::Node::Blank')) {
 		$node_label	= $node->blank_identifier;
 		$node_label	=~ s/&/&amp;/g;
