@@ -7,19 +7,23 @@ RDF::Trine::Iterator::Boolean - Stream (iterator) class for boolean query result
 
 =head1 VERSION
 
-This document describes RDF::Trine::Iterator::Boolean version 0.130_01
+This document describes RDF::Trine::Iterator::Boolean version 0.130_02
 
 =head1 SYNOPSIS
 
-    use RDF::Trine::Iterator::Boolean;
-    
-    my $iterator = RDF::Trine::Iterator::Boolean->new( [1] );
-    if ($iterator->get_boolean) {
-    	# ...
-    }
+ use RDF::Trine::Iterator::Boolean;
+ 
+ my $iterator = RDF::Trine::Iterator::Boolean->new( [1] );
+ my $bool = $iterator->get_boolean;
+ if ($bool) {
+ 	print "Yes.\n";
+ }
 
 =head1 METHODS
 
+Beyond the methods documented below, this class inherits methods from the
+L<RDF::Trine::Iterator> class.
+
 =over 4
 
 =cut
@@ -34,7 +38,7 @@ use JSON 2.0;
 use base qw(RDF::Trine::Iterator);
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.130_01';
+	$VERSION	= '0.130_02';
 }
 
 =item C<new ( \@results, %args )>
