@@ -7,19 +7,23 @@ RDF::Trine::Iterator::Graph - Stream (iterator) class for graph query results
 
 =head1 VERSION
 
-This document describes RDF::Trine::Iterator::Graph version 0.130_01
+This document describes RDF::Trine::Iterator::Graph version 0.130_02
 
 =head1 SYNOPSIS
 
-    use RDF::Trine::Iterator;
-    
-    my $iterator = RDF::Trine::Iterator::Graph->new( \&data );
-    while (my $statement = $iterator->next) {
-    	# do something with $statement
-    }
+ use RDF::Trine::Iterator::Graph;
+ 
+ my $iterator = RDF::Trine::Iterator::Graph->new( \&data );
+ while (my $st = $iterator->next) {
+   # $st is a RDF::Trine::Statement object
+   print $st->as_string;
+ }
 
 =head1 METHODS
 
+Beyond the methods documented below, this class inherits methods from the
+L<RDF::Trine::Iterator> class.
+
 =over 4
 
 =cut
@@ -43,7 +47,7 @@ use base qw(RDF::Trine::Iterator);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.130_01';
+	$VERSION	= '0.130_02';
 }
 
 ######################################################################
