@@ -7,10 +7,13 @@ RDF::Trine::Model::StatementFilter - Model for filtering statements based on a u
 
 =head1 VERSION
 
-This document describes RDF::Trine::Model::StatementFilter version 0.130_01
+This document describes RDF::Trine::Model::StatementFilter version 0.130_02
 
 =head1 METHODS
 
+Beyond the methods documented below, this class inherits methods from the
+L<RDF::Trine::Model> class.
+
 =over 4
 
 =cut
@@ -31,7 +34,7 @@ use RDF::Trine::Iterator qw(sgrep);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.130_01';
+	$VERSION	= '0.130_02';
 }
 
 ################################################################################
