@@ -7,7 +7,7 @@ RDF::Trine::Parser::NQuads - N-Quads Parser
 
 =head1 VERSION
 
-This document describes RDF::Trine::Parser::NQuads version 0.130_01
+This document describes RDF::Trine::Parser::NQuads version 0.130_02
 
 =head1 SYNOPSIS
 
@@ -21,6 +21,9 @@ This document describes RDF::Trine::Parser::NQuads version 0.130_01
 
 =head1 METHODS
 
+Beyond the methods documented below, this class inherits methods from the
+L<RDF::Trine::Parser> class.
+
 =over 4
 
 =cut
@@ -48,7 +51,7 @@ use RDF::Trine::Error qw(:try);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.130_01';
+	$VERSION	= '0.130_02';
 	$RDF::Trine::Parser::parser_names{ 'nquads' }	= __PACKAGE__;
 	$RDF::Trine::Parser::format_uris{ 'http://sw.deri.org/2008/07/n-quads/#n-quads' }	= __PACKAGE__;
 	foreach my $ext (qw(nq)) {
