@@ -7,7 +7,7 @@ RDF::Trine::Serializer::Turtle - Turtle Serializer
 
 =head1 VERSION
 
-This document describes RDF::Trine::Serializer::Turtle version 0.130_01
+This document describes RDF::Trine::Serializer::Turtle version 0.130_02
 
 =head1 SYNOPSIS
 
@@ -23,6 +23,9 @@ and where possible the more concise syntax is used for rdf:Lists.
 
 =head1 METHODS
 
+Beyond the methods documented below, this class inherits methods from the
+L<RDF::Trine::Serializer> class.
+
 =over 4
 
 =cut
@@ -49,7 +52,7 @@ use RDF::Trine::Namespace qw(rdf);
 our ($VERSION, $debug);
 BEGIN {
 	$debug		= 0;
-	$VERSION	= '0.130_01';
+	$VERSION	= '0.130_02';
 	$RDF::Trine::Serializer::serializer_names{ 'turtle' }	= __PACKAGE__;
 	$RDF::Trine::Serializer::format_uris{ 'http://www.w3.org/ns/formats/Turtle' }	= __PACKAGE__;
 	foreach my $type (qw(application/x-turtle application/turtle text/turtle)) {
@@ -121,7 +124,7 @@ sub serialize_model_to_string {
 	my $self	= shift;
 	my $model	= shift;
 	my $string	= '';
-	open( my $fh, '>', \$string );
+	open( my $fh, '>:utf8', \$string );
 	$self->serialize_model_to_file( $fh, $model, seen => {}, levell => 0, tab => "\t", @_, model => $model, string => 1 );
 	close($fh);
 	return $string;
@@ -153,7 +156,7 @@ sub serialize_iterator_to_file {
 		$tmp_buffer	= '';
 		$tmp_fh	= $fh;
 		$fh		= undef;
-		open( $fh, '>', \$tmp_buffer );
+		open( $fh, '>:utf8', \$tmp_buffer );
 	} else {
 		if (@nskeys) {
 			foreach my $ns (@nskeys) {
@@ -298,7 +301,7 @@ sub serialize_iterator_to_string {
 	my $self	= shift;
 	my $iter	= shift;
 	my $string	= '';
-	open( my $fh, '>', \$string );
+	open( my $fh, '>:utf8', \$string );
 	$self->serialize_iterator_to_file( $fh, $iter, seen => {}, level => 0, tab => "\t", @_, string => 1 );
 	close($fh);
 	return $string;
@@ -527,7 +530,7 @@ sub _node_concise_string {
 			my $qname;
 			try {
 				my ($ns,$local)	= $dtr->qname;
-				if (exists $self->{ns}{$ns}) {
+				if (blessed($self) and exists $self->{ns}{$ns}) {
 					$qname	= join(':', $self->{ns}{$ns}, $local);
 					$self->{used_ns}{ $self->{ns}{$ns} }++;
 				}
@@ -541,7 +544,7 @@ sub _node_concise_string {
 		my $value;
 		try {
 			my ($ns,$local)	= $obj->qname;
-			if (exists $self->{ns}{$ns}) {
+			if (blessed($self) and exists $self->{ns}{$ns}) {
 				$value	= join(':', $self->{ns}{$ns}, $local);
 				$self->{used_ns}{ $self->{ns}{$ns} }++;
 			}
